@@ -19,6 +19,7 @@ import java.io.* ;
 
 public class Hello {
     int foo = 1998 ;
+    int hex_foo = 0xCAFEBABE;
     boolean b ;
     Integer i = null ;
     char c = '\'', d = 'n', e = '\\' ;
@@ -28,7 +29,7 @@ public class Hello {
 	// just some greetings ;-)  /*
 	System.out.println( "Hello from java2html :-)" ) ;
 	System.out.println( "\tby Lorenzo Bettini" ) ;
-	System.out.println( "\tlorenzo.bettini@penteres.it" ) ;
+	System.out.println( "\tbettini@gnu.org" ) ;
         //System.out.println( "bye bye... :-D" ) ; // see you soon
     }
 }
